@@ -21,14 +21,21 @@ def prepare_tags(k):
     return k
 
 
-def add_datapoint(time_series_dict, broader_ts_name, start_time_ms, metric_value, tags_array):
+def add_datapoint(
+    time_series_dict, broader_ts_name, start_time_ms, metric_value, tags_array
+):
     if broader_ts_name not in time_series_dict:
         tags_dict = {}
         for tag_kv in tags_array:
             k = list(tag_kv.keys())[0]
             v = list(tag_kv.values())[0]
             tags_dict[k] = v
-        time_series_dict[broader_ts_name] = {"index": [], "data": [], "tags-array": tags_array, "tags": tags_dict}
+        time_series_dict[broader_ts_name] = {
+            "index": [],
+            "data": [],
+            "tags-array": tags_array,
+            "tags": tags_dict,
+        }
     time_series_dict[broader_ts_name]["index"].append(start_time_ms)
     time_series_dict[broader_ts_name]["data"].append(metric_value)
 
@@ -66,17 +73,40 @@ def get_or_None(dict, property):
     return result
 
 
-def get_kv_tags(deployment_type, extra_tags_array, git_sha, project, project_version, results_type, step,
-                testcase_name):
+def get_kv_tags(
+    deployment_type,
+    extra_tags_array,
+    git_sha,
+    project,
+    project_version,
+    results_type,
+    step,
+    testcase_name,
+):
     common_broader_kv_tags = [
-        {"project": project}, {"use-case": testcase_name}, {"deployment-type": deployment_type},
-        {"results-type": results_type}, {"step": step}]
+        {"project": project},
+        {"use-case": testcase_name},
+        {"deployment-type": deployment_type},
+        {"results-type": results_type},
+        {"step": step},
+    ]
     common_broader_kv_tags.extend(extra_tags_array)
     common_version_kv_tags = [
-        {"project": project}, {"use-case": testcase_name}, {"deployment-type": deployment_type},
-        {"results-type": results_type}, {"step": step}, {"version": project_version}]
+        {"project": project},
+        {"use-case": testcase_name},
+        {"deployment-type": deployment_type},
+        {"results-type": results_type},
+        {"step": step},
+        {"version": project_version},
+    ]
     common_version_kv_tags.extend(extra_tags_array)
     common_git_sha_kv_tags = [
-        {"project": project}, {"use-case": testcase_name}, {"deployment-type": deployment_type},
-        {"results-type": results_type}, {"step": step}, {"version": project_version}, {"git_sha": git_sha}]
+        {"project": project},
+        {"use-case": testcase_name},
+        {"deployment-type": deployment_type},
+        {"results-type": results_type},
+        {"step": step},
+        {"version": project_version},
+        {"git_sha": git_sha},
+    ]
     return common_broader_kv_tags, common_git_sha_kv_tags, common_version_kv_tags
