@@ -13,11 +13,21 @@ from rediscluster import RedisCluster
 from tqdm import tqdm
 
 from redisbench_admin.compare.compare import generate_comparison_dataframe_configs
-from redisbench_admin.run.ftsb_redisearch.ftsb_redisearch import run_ftsb_redisearch, get_run_options
+from redisbench_admin.run.ftsb_redisearch.ftsb_redisearch import (
+    run_ftsb_redisearch,
+    get_run_options,
+)
 from redisbench_admin.utils.redisearch import check_and_extract_redisearch_info
 from redisbench_admin.utils.results import from_resultsDF_to_key_results_dict
-from redisbench_admin.utils.utils import required_utilities, whereis, decompress_file, findJsonPath, ts_milli, \
-    retrieve_local_or_remote_input_json, upload_artifacts_to_s3
+from redisbench_admin.utils.utils import (
+    required_utilities,
+    whereis,
+    decompress_file,
+    findJsonPath,
+    ts_milli,
+    retrieve_local_or_remote_input_json,
+    upload_artifacts_to_s3,
+)
 
 
 def run_command_logic(args):
@@ -37,25 +47,31 @@ def run_command_logic(args):
         run_only_steps = args.run_only_steps.split(",")
 
     benchmark_machine_info = cpuinfo.get_cpu_info()
-    total_cores = benchmark_machine_info['count']
-    benchmark_infra = {"total-benchmark-machines": 0, "benchmark-machines": {}, "total-db-machines": 0,
-                       "db-machines": {}}
+    total_cores = benchmark_machine_info["count"]
+    benchmark_infra = {
+        "total-benchmark-machines": 0,
+        "benchmark-machines": {},
+        "total-db-machines": 0,
+        "db-machines": {},
+    }
     benchmark_machine_1 = {"machine_info": benchmark_machine_info}
     benchmark_infra["benchmark-machines"]["benchmark-machine-1"] = benchmark_machine_1
     benchmark_infra["total-benchmark-machines"] += 1
     if workers == 0:
-        print('Setting number of workers equal to machine VCPUs {}'.format(total_cores))
+        print("Setting number of workers equal to machine VCPUs {}".format(total_cores))
         workers = total_cores
     else:
-        print('Setting number of workers to {}'.format(workers))
+        print("Setting number of workers to {}".format(workers))
 
-    print('Setting pipeline to {}'.format(pipeline))
+    print("Setting pipeline to {}".format(pipeline))
 
     deployment_type = args.deployment_type
     config_filename = args.benchmark_config_file
-    benchmark_config = retrieve_local_or_remote_input_json(config_filename, local_path, "--benchmark-config-file")
+    benchmark_config = retrieve_local_or_remote_input_json(
+        config_filename, local_path, "--benchmark-config-file"
+    )
     if benchmark_config is None:
-        print('Error while retrieving {}! Exiting..'.format(config_filename))
+        print("Error while retrieving {}! Exiting..".format(config_filename))
         sys.exit(1)
 
     benchmark_config = list(benchmark_config.values())[0]
@@ -67,10 +83,14 @@ def run_command_logic(args):
 
     deployment_requirements = benchmark_config["deployment-requirements"]
     required_utilities_list = deployment_requirements["utilities"].keys()
-    print("Checking required utilities are in place ({})".format(" ".join(required_utilities_list)))
+    print(
+        "Checking required utilities are in place ({})".format(
+            " ".join(required_utilities_list)
+        )
+    )
 
     if required_utilities(required_utilities_list) == 0:
-        print('Utilities Missing! Exiting..')
+        print("Utilities Missing! Exiting..")
         sys.exit(1)
     benchmark_tool = deployment_requirements["benchmark-tool"]
     print(benchmark_tool)
@@ -78,11 +98,14 @@ def run_command_logic(args):
     if benchmark_tool_path is None:
         benchmark_tool_path = benchmark_tool
 
-    s3_bucket_path = "{project}/results/{test_name}/".format(project=project, test_name=test_name)
+    s3_bucket_path = "{project}/results/{test_name}/".format(
+        project=project, test_name=test_name
+    )
     if args.output_file_prefix != "":
         s3_bucket_path = "{}{}/".format(s3_bucket_path, args.output_file_prefix)
-    s3_uri = "https://s3.amazonaws.com/{bucket_name}/{bucket_path}".format(bucket_name=s3_bucket_name,
-                                                                           bucket_path=s3_bucket_path)
+    s3_uri = "https://s3.amazonaws.com/{bucket_name}/{bucket_path}".format(
+        bucket_name=s3_bucket_name, bucket_path=s3_bucket_path
+    )
     run_stages = benchmark_config["run-stages"]
     benchmark_output_dict = {
         "key-configs": {},
@@ -90,24 +113,35 @@ def run_command_logic(args):
         "benchmark-config": benchmark_config,
         "setup": {},
         "benchmark": {},
-        "infastructure": benchmark_infra
+        "infastructure": benchmark_infra,
     }
     print("Checking required inputs are in place...")
     benchmark_inputs_dict = benchmark_config["inputs"]
-    run_stages_inputs = check_and_get_inputs(benchmark_inputs_dict, local_path, run_stages)
+    run_stages_inputs = check_and_get_inputs(
+        benchmark_inputs_dict, local_path, run_stages
+    )
     aux_client = None
 
     print("Checking required modules available at {}...".format(args.redis_url))
     key_configs_git_sha = None
     key_configs_version = None
     server_info = None
-    redisearch_benchmark = True if "ft" in deployment_requirements["redis-server"]["modules"] else False
+    redisearch_benchmark = (
+        True if "ft" in deployment_requirements["redis-server"]["modules"] else False
+    )
     if redisearch_benchmark:
-        key_configs_git_sha, key_configs_version, server_info = check_and_extract_redisearch_info(args.redis_url)
+        (
+            key_configs_git_sha,
+            key_configs_version,
+            server_info,
+        ) = check_and_extract_redisearch_info(args.redis_url)
 
-    key_configs = {"deployment-type": deployment_type,
-                   "deployment-shards": args.deployment_shards,
-                   "version": key_configs_version, "git_sha": key_configs_git_sha}
+    key_configs = {
+        "deployment-type": deployment_type,
+        "deployment-shards": args.deployment_shards,
+        "version": key_configs_version,
+        "git_sha": key_configs_git_sha,
+    }
 
     db_machine_1 = {"machine_info": None, "redis_info": server_info}
     benchmark_infra["db-machines"]["db-machine-1"] = db_machine_1
@@ -120,7 +154,8 @@ def run_command_logic(args):
     options = get_run_options()
     start_time = dt.datetime.now()
     benchmark_repetitions_require_teardown = benchmark_config["benchmark"][
-        "repetitions-require-teardown-and-re-setup"]
+        "repetitions-require-teardown-and-re-setup"
+    ]
     total_steps = args.repetitions + len(run_stages) - 1
     if benchmark_repetitions_require_teardown is True:
         total_steps += total_steps
@@ -128,25 +163,45 @@ def run_command_logic(args):
     for repetition in range(1, args.repetitions + 1):
         if benchmark_repetitions_require_teardown is True or repetition == 1:
             if skip_setup is False:
-                aux_client = run_setup_commands(args, "setup", benchmark_config["setup"]["commands"], oss_cluster_mode)
+                aux_client = run_setup_commands(
+                    args,
+                    "setup",
+                    benchmark_config["setup"]["commands"],
+                    oss_cluster_mode,
+                )
             else:
-                print("Implicitly skipping setup commands due to --skip-setup-commands flag")
+                print(
+                    "Implicitly skipping setup commands due to --skip-setup-commands flag"
+                )
             if "setup" in run_stages_inputs:
                 run_setup_step = True
                 if run_only_steps is not None and "setup" not in run_only_steps:
                     run_setup_step = False
                 if run_setup_step:
                     setup_run_key = "setup-run-{}.json".format(repetition)
-                    setup_run_json_output_fullpath = "{}/{}".format(local_path, setup_run_key)
+                    setup_run_json_output_fullpath = "{}/{}".format(
+                        local_path, setup_run_key
+                    )
                     input_file = run_stages_inputs["setup"]
-                    benchmark_output_dict["setup"][setup_run_key] = run_ftsb_redisearch(args.redis_url,
-                                                                                        benchmark_tool_path,
-                                                                                        setup_run_json_output_fullpath,
-                                                                                        options, input_file, workers,
-                                                                                        pipeline, oss_cluster_mode, 0,
-                                                                                        0, continue_on_error)
+                    benchmark_output_dict["setup"][setup_run_key] = run_ftsb_redisearch(
+                        args.redis_url,
+                        benchmark_tool_path,
+                        setup_run_json_output_fullpath,
+                        options,
+                        input_file,
+                        workers,
+                        pipeline,
+                        oss_cluster_mode,
+                        0,
+                        0,
+                        continue_on_error,
+                    )
                 else:
-                    print("Skipping setup step since it's not present in: {}".format(run_only_steps))
+                    print(
+                        "Skipping setup step since it's not present in: {}".format(
+                            run_only_steps
+                        )
+                    )
             progress.update()
 
         ######################
@@ -158,25 +213,47 @@ def run_command_logic(args):
 
         if run_benchmark_step:
             benchmark_run_key = "benchmark-run-{}.json".format(repetition)
-            benchmark_run_json_output_fullpath = "{}/{}".format(local_path, benchmark_run_key)
+            benchmark_run_json_output_fullpath = "{}/{}".format(
+                local_path, benchmark_run_key
+            )
             input_file = run_stages_inputs["benchmark"]
 
-            benchmark_output_dict["benchmark"][benchmark_run_key] = run_ftsb_redisearch(args.redis_url,
-                                                                                        benchmark_tool_path,
-                                                                                        benchmark_run_json_output_fullpath,
-                                                                                        options, input_file, workers,
-                                                                                        pipeline, oss_cluster_mode,
-                                                                                        max_rps, requests,
-                                                                                        continue_on_error)
+            benchmark_output_dict["benchmark"][benchmark_run_key] = run_ftsb_redisearch(
+                args.redis_url,
+                benchmark_tool_path,
+                benchmark_run_json_output_fullpath,
+                options,
+                input_file,
+                workers,
+                pipeline,
+                oss_cluster_mode,
+                max_rps,
+                requests,
+                continue_on_error,
+            )
         else:
-            print("Skipping benchmark step since it's not present in: {}".format(run_only_steps))
+            print(
+                "Skipping benchmark step since it's not present in: {}".format(
+                    run_only_steps
+                )
+            )
 
-        if benchmark_repetitions_require_teardown is True or repetition == args.repetitions:
+        if (
+            benchmark_repetitions_require_teardown is True
+            or repetition == args.repetitions
+        ):
             if skip_teardown is False:
                 print("Running tear down steps...")
-                run_setup_commands(args, "tear down", benchmark_config["teardown"]["commands"], oss_cluster_mode)
+                run_setup_commands(
+                    args,
+                    "tear down",
+                    benchmark_config["teardown"]["commands"],
+                    oss_cluster_mode,
+                )
             else:
-                print("Implicitly skipping teardown commands due to --skip-teardown-commands flag")
+                print(
+                    "Implicitly skipping teardown commands due to --skip-teardown-commands flag"
+                )
 
         progress.update()
     end_time = dt.datetime.now()
@@ -191,30 +268,43 @@ def run_command_logic(args):
         if run_only_steps is not None and step not in run_only_steps:
             for run_name, result_run in benchmark_output_dict[step].items():
                 step_df_dict[step]["df_dict"]["run-name"].append(run_name)
-                for pos, metric_json_path in enumerate(step_df_dict[step]["metric_json_path"]):
+                for pos, metric_json_path in enumerate(
+                    step_df_dict[step]["metric_json_path"]
+                ):
                     metric_name = step_df_dict[step]["sorting_metric_names"][pos]
                     metric_value = None
                     try:
                         metric_value = findJsonPath(metric_json_path, result_run)
                     except KeyError:
                         print(
-                            "Error retrieving {} metric from JSON PATH {} on file {}".format(metric_name,
-                                                                                             metric_json_path,
-                                                                                             run_name))
+                            "Error retrieving {} metric from JSON PATH {} on file {}".format(
+                                metric_name, metric_json_path, run_name
+                            )
+                        )
                         pass
                     step_df_dict[step]["df_dict"][metric_name].append(metric_value)
             resultsDataFrame = pd.DataFrame(step_df_dict[step]["df_dict"])
-            resultsDataFrame.sort_values(step_df_dict[step]["sorting_metric_names"],
-                                         ascending=step_df_dict[step]["sorting_metric_sorting_direction"], inplace=True)
-            benchmark_output_dict["key-results"][step] = from_resultsDF_to_key_results_dict(resultsDataFrame, step,
-                                                                                            step_df_dict)
+            resultsDataFrame.sort_values(
+                step_df_dict[step]["sorting_metric_names"],
+                ascending=step_df_dict[step]["sorting_metric_sorting_direction"],
+                inplace=True,
+            )
+            benchmark_output_dict["key-results"][
+                step
+            ] = from_resultsDF_to_key_results_dict(resultsDataFrame, step, step_df_dict)
     #####################
     # Run Info Metadata #
     #####################
     run_info, start_time_str = prepare_run_info_metadata_dict(end_time, start_time)
     benchmark_output_dict["run-info"] = run_info
-    benchmark_output_filename = get_run_ftsb_redisearch_full_filename(args, deployment_type, key_configs_git_sha,
-                                                                      key_configs_version, start_time_str, test_name)
+    benchmark_output_filename = get_run_ftsb_redisearch_full_filename(
+        args,
+        deployment_type,
+        key_configs_git_sha,
+        key_configs_version,
+        start_time_str,
+        test_name,
+    )
     with open(benchmark_output_filename, "w") as json_out_file:
         json.dump(benchmark_output_dict, json_out_file, indent=2)
 
@@ -231,19 +321,25 @@ def run_setup_commands(args, step_string_description, commands, cluster_enabled)
             host = host_port_arr[0]
             port = host_port_arr[1]
             startup_nodes = [{"host": host, "port": port}]
-            aux_client = RedisCluster(startup_nodes=startup_nodes, decode_responses=True)
+            aux_client = RedisCluster(
+                startup_nodes=startup_nodes, decode_responses=True
+            )
             cluster_nodes = aux_client.cluster_nodes()
             for command in commands:
                 for master_node in aux_client.connection_pool.nodes.all_masters():
-                    redis.from_url("redis://" + master_node["name"]).execute_command(" ".join(command))
+                    redis.from_url("redis://" + master_node["name"]).execute_command(
+                        " ".join(command)
+                    )
         else:
             aux_client = redis.from_url(args.redis_url)
             for command in commands:
                 aux_client.execute_command(" ".join(command))
     except redis.connection.ConnectionError as e:
-        print('Error while issuing {} steps command to Redis.Command {}! Error message: {} Exiting..'.format(
-            step_string_description, command,
-            e.__str__()))
+        print(
+            "Error while issuing {} steps command to Redis.Command {}! Error message: {} Exiting..".format(
+                step_string_description, command, e.__str__()
+            )
+        )
         sys.exit(1)
     return aux_client
 
@@ -255,9 +351,14 @@ def prepare_run_info_metadata_dict(end_time, start_time):
     start_time_ms = ts_milli(start_time)
     end_time_ms = ts_milli(end_time)
     duration_humanized = humanize.naturaldelta((end_time - start_time))
-    run_info = {"start-time-ms": start_time_ms, "start-time-humanized": start_time_str, "end-time-ms": end_time_ms,
-                "end-time-humanized": end_time_str, "duration-ms": duration_ms,
-                "duration-humanized": duration_humanized}
+    run_info = {
+        "start-time-ms": start_time_ms,
+        "start-time-humanized": start_time_str,
+        "end-time-ms": end_time_ms,
+        "end-time-humanized": end_time_str,
+        "duration-ms": duration_ms,
+        "duration-humanized": duration_humanized,
+    }
     return run_info, start_time_str
 
 
@@ -267,31 +368,51 @@ def check_and_get_inputs(benchmark_inputs_dict, local_path, run_stages):
         remote_url = input_description["remote-url"]
         local_uncompressed_filename = input_description["local-uncompressed-filename"]
         local_compressed_filename = input_description["local-compressed-filename"]
-        local_uncompressed_filename_path = "{}/{}".format(local_path, local_uncompressed_filename)
-        local_compressed_filename_path = "{}/{}".format(local_path, local_compressed_filename)
+        local_uncompressed_filename_path = "{}/{}".format(
+            local_path, local_uncompressed_filename
+        )
+        local_compressed_filename_path = "{}/{}".format(
+            local_path, local_compressed_filename
+        )
         local_uncompressed_exists = os.path.isfile(local_uncompressed_filename_path)
         local_compressed_exists = os.path.isfile(local_compressed_filename_path)
         if stage in run_stages:
             # if the local uncompressed file exists dont need to do work
             if local_uncompressed_exists:
                 print(
-                    "\tLocal uncompressed file {} exists at {}. Nothing to do here".format(local_uncompressed_filename,
-                                                                                           local_uncompressed_filename_path))
+                    "\tLocal uncompressed file {} exists at {}. Nothing to do here".format(
+                        local_uncompressed_filename, local_uncompressed_filename_path
+                    )
+                )
             # if the local compressed file exists then we need to uncompress it
             elif local_compressed_exists:
-                print("\tLocal compressed file {} exists at {}. Uncompressing it".format(local_uncompressed_filename,
-                                                                                         local_uncompressed_filename_path))
-                decompress_file(local_compressed_filename_path, local_uncompressed_filename_path)
+                print(
+                    "\tLocal compressed file {} exists at {}. Uncompressing it".format(
+                        local_uncompressed_filename, local_uncompressed_filename_path
+                    )
+                )
+                decompress_file(
+                    local_compressed_filename_path, local_uncompressed_filename_path
+                )
 
             elif remote_url is not None:
-                print("\tRetrieving {} and saving to {}".format(remote_url, local_compressed_filename_path))
+                print(
+                    "\tRetrieving {} and saving to {}".format(
+                        remote_url, local_compressed_filename_path
+                    )
+                )
                 r = requests.get(remote_url)
-                open(local_compressed_filename_path, 'wb').write(r.content)
-                decompress_file(local_compressed_filename_path, local_uncompressed_filename_path)
+                open(local_compressed_filename_path, "wb").write(r.content)
+                decompress_file(
+                    local_compressed_filename_path, local_uncompressed_filename_path
+                )
 
             else:
-                print('\tFor stage {}, unable to retrieve required file {}! Exiting..'.format(stage,
-                                                                                              local_uncompressed_filename))
+                print(
+                    "\tFor stage {}, unable to retrieve required file {}! Exiting..".format(
+                        stage, local_uncompressed_filename
+                    )
+                )
                 sys.exit(1)
 
             run_stages_inputs[stage] = local_uncompressed_filename_path
@@ -299,10 +420,20 @@ def check_and_get_inputs(benchmark_inputs_dict, local_path, run_stages):
     return run_stages_inputs
 
 
-def get_run_ftsb_redisearch_full_filename(args, deployment_type, redisearch_git_sha, redisearch_version, start_time_str,
-                                          test_name):
+def get_run_ftsb_redisearch_full_filename(
+    args,
+    deployment_type,
+    redisearch_git_sha,
+    redisearch_version,
+    start_time_str,
+    test_name,
+):
     benchmark_output_filename = "{prefix}{time_str}-{deployment_type}-{use_case}-{version}-{git_sha}.json".format(
         prefix=args.output_file_prefix,
-        time_str=start_time_str, deployment_type=deployment_type, use_case=test_name,
-        version=redisearch_version, git_sha=redisearch_git_sha)
+        time_str=start_time_str,
+        deployment_type=deployment_type,
+        use_case=test_name,
+        version=redisearch_version,
+        git_sha=redisearch_git_sha,
+    )
     return benchmark_output_filename
